@@ -249,8 +249,8 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
         :rtype: generator
         """
         from django.conf import settings
-        # Значение PAGE_LIMIT по умолчанию 1. С большим PAGE_LIMIT можно заддосить ГАР
-        page_limit = settings.GAR.get('PAGE_LIMIT', 1)
+        # Значение PAGE_LIMIT по умолчанию 5. С большим PAGE_LIMIT можно заддосить ГАР
+        page_limit = settings.GAR.get('PAGE_LIMIT', 5)
 
         if page is None:
             pages = count(start=1)
@@ -429,6 +429,68 @@ class PlaceLoader(AddressObjectLoaderBase):
     def _sort_key(self, object_data):
         return object_data['level'], object_data['fullName'] or ''
 
+    def load_raw(self, page=None):
+        from django.conf import settings
+
+        def get_page_counter():
+            if page is None:
+                pages = count(start=1)
+            else:
+                pages = range(page, page + 1)
+
+            return pages
+
+        # Значение PAGE_LIMIT по умолчанию 1. С большим PAGE_LIMIT можно заддосить ГАР
+        page_limit = settings.GAR.get('PAGE_LIMIT', 1)
+
+        # Нам могут передать что-то вроде "Новосибирск, Маяк". В этом случае
+        # все части, кроме последней - это потенциальные фильтры по родителям
+        filter_parts = [x.strip() for x in self.filter_string.split(',') if x]
+        filter_count = len(filter_parts)
+        parent_ids = set()
+
+        for index, part in enumerate(filter_parts, start=1):
+            self.filter_string = part
+
+            if index == filter_count:
+                # Дошли до последнего элемента, будем искать по родителям
+                for parent_id in parent_ids or set([None]):
+                    self._parent_id = parent_id
+                    # Приходится собирать для каждого родителя
+                    params = self._get_params()
+
+                    for page_number in get_page_counter():
+                        drf_data = self._load_page(params, page_number)
+                        if drf_data:
+                            for drf_object_data in drf_data['results']:
+                                object_data = self._process_object_data(drf_object_data)
+                                if self._filter(object_data):
+                                    yield object_data
+
+                            if not drf_data['next'] or page_number >= page_limit:
+                                break
+                        else:
+                            break
+
+            else:
+                # Займемся поиском родителей
+                params = self._get_params()
+
+                for page_number in count(start=1):
+                    #  Не ограничиваем поиск колчиество страницы, чтобы не
+                    #  потерять результаты
+                    drf_data = self._load_page(params, page_number)
+
+                    if drf_data:
+                        for drf_object_data in drf_data['results']:
+                            parent_ids.add(drf_object_data['objectguid'])
+
+                        if not drf_data['next']:
+                            break
+
+                    else:
+                        break
+
 
 class StreetLoader(AddressObjectLoaderBase):
     """
